@@ -4,7 +4,7 @@
 #' 
 #' The \code{errorlocation} objects consists of the following slots wich can be 
 #' accessed with the dollar operator, just like with lists. Right now the only
-#' function creating such objects is \code{\link{localizeErrors}}
+#' functions creating such objects are \code{\link{localizeErrors}} and \code{\link{checkDatamodel}}.
 #'
 #' \itemize{
 #'      \item{\code{adapt} a \code{logical} array where each row/column shows which record/variable should be adapted.}
@@ -19,14 +19,19 @@
 #'              \item{\code{maxDurationExceeded} Was the maximum search time reached?}
 #'          }
 #'      }
-#'      \item{\code{method} The error localization method used, can be "mip" or "localizer".}
-#'      \item{\code{call} The R call to the function generating the object.}
+#'      \item{\code{method} The error localization method used, can be "mip", "localizer" or "checkDatamodel".}
+#'      \item{\code{call} The R calls to the function generating the object.}
 #'      \item{\code{user} \code{character} user who generated the object.}
 #'      \item{\code{timestamp} \code{character} timestamp.}
 #' }
+#'
+#' It is possible to \code{plot} objects of class \code{errorLocation}. An overview containing
+#' three or four graphs will be plotted in a new window. Axes in scatterplots are set to logarithmic
+#' if their scales maxima exceed 50.
+#'
 #' @rdname errorLocation
 #' @name errorLocation
-#' @seealso \code{\link{localizeErrors}}
+#' @seealso \code{\link{localizeErrors}}, \code{\link{checkDatamodel}}
 {}
 
 
@@ -53,12 +58,25 @@ newerrorlocation <- function(adapt, status, call=sys.call(-1), method, user=Sys.
     ) 
 }
 
+
+# empty errorLocation object for a data.frame adapt array
+emptyerrorlocation <- function(dat, ...){
+    m <- nrow(dat)
+    n <- ncol(dat)
+    newerrorlocation(
+        array(FALSE,dim=c(m,n),dimnames=dimnames(dat)),
+        status = emptyStatus(m),
+        ...
+    )
+}
+
+
 #' Print object of class errorLocation 
 #'
 #' @param x object of class errorLocation
 #' @param ... arguments to be passed to other methods
 #' @method print errorLocation
-#' @rdname print
+#' @keywords internal
 #' @export
 print.errorLocation <- function(x,...){
     cat("Object of class 'errorLocation' generated at",x$timestamp,'\n')
@@ -94,6 +112,7 @@ print.errorLocation <- function(x,...){
 # @name plus
 # @rdname plus
 `%+%` <- function(x,y,...){
+    if ( is.null(y) ) return(x)
     UseMethod("%+%")
 }
 
@@ -103,7 +122,7 @@ print.errorLocation <- function(x,...){
 # 
 # @rdname plus
 `%+%.errorLocation` <- function(x,y,...){
-   stopifnot( class(y) == 'errorLocation' )
+    stopifnot( class(y) == 'errorLocation' )
     call <- unique(c(x$call,y$call))
     if (length(call) == 1) call <- call[[1]]
     newerrorlocation(    
